===============
TeleBot version
===============

.. meta::
   :description: Synchronous pyTelegramBotAPI documentation
   :keywords: ptba, pytba, pyTelegramBotAPI, methods, guide, files, sync

TeleBot methods
---------------
.. automodule:: telebot
   :members:
   :undoc-members:
   :show-inheritance:

custom_filters file
------------------------------

.. automodule:: telebot.custom_filters
   :members:
   :undoc-members:
   :show-inheritance:

handler_backends file
--------------------------------

.. automodule:: telebot.handler_backends
   :members:
   :undoc-members:
   :show-inheritance:


Extensions
------------------------



.. automodule:: telebot.ext.sync.webhooks
   :members:
   :undoc-members:
   :show-inheritance: